@@ -69,6 +69,10 @@ typedef struct
 typedef enum {
         /* gsm's own startup/initialization phase */
         GSM_MANAGER_PHASE_STARTUP = 0,
+        /* gnome-initial-setup */
+        GSM_MANAGER_PHASE_EARLY_INITIALIZATION,
+        /* wayland compositor and XWayland */
+        GSM_MANAGER_PHASE_DISPLAY_SERVER,
         /* xrandr setup, gnome-settings-daemon, etc */
         GSM_MANAGER_PHASE_INITIALIZATION,
         /* window/compositing managers */
@@ -157,9 +161,9 @@ gboolean            gsm_manager_is_inhibited                   (GsmManager
                                                                 GError                *error);
 
 gboolean            gsm_manager_shutdown                       (GsmManager     *manager,
-                                                                GError        **error);
+                                                                DBusGMethodInvocation *context);
 gboolean            gsm_manager_reboot                         (GsmManager     *manager,
-                                                                GError        **error);
+                                                                DBusGMethodInvocation *context);
 
 gboolean            gsm_manager_can_shutdown                   (GsmManager     *manager,
                                                                 gboolean       *shutdown_available,
